@@ -297,9 +297,9 @@ without the need to rewrite the file since their values are not contained
 within the file data.
 },
     Composite => q{
-The values of the composite tags are derived from the values of other tags.
-These are convenience tags which are calculated after all other information
-is extracted.
+The values of the composite tags are B<Derived From> the values of other
+tags.  These are convenience tags which are calculated after all other
+information is extracted.
 },
     Shortcuts => q{
 Shortcut tags are convenience tags that represent one or more other tag
@@ -539,7 +539,7 @@ TagID:  foreach $tagID (@keys) {
                                 my $index;
                                 if ($$tagInfo{PrintHex} or $$printConv{BITMASK}) {
                                     $index = sprintf('0x%x',$_);
-                                } elsif (/^[-+]?\d+$/) {
+                                } elsif (/^[+-]?(?=\d|\.\d)\d*(\.\d*)?$/) {
                                     $index = $_;
                                 } else {
                                     $index = $_;
@@ -868,8 +868,8 @@ sub NumbersFirst
     } else {
         my ($a2, $b2) = ($a, $b);
         # expand numbers to 3 digits (with restrictions to avoid messing up ascii-hex tags)
-        $a2 =~ s/(\d+)/sprintf("%.3d",$1)/eg if $a2 =~ /^(APP)?[0-9 ]*$/ and length($a2)<16;
-        $b2 =~ s/(\d+)/sprintf("%.3d",$1)/eg if $b2 =~ /^(APP)?[0-9 ]*$/ and length($b2)<16;
+        $a2 =~ s/(\d+)/sprintf("%.3d",$1)/eg if $a2 =~ /^(APP)?[.0-9 ]*$/ and length($a2)<16;
+        $b2 =~ s/(\d+)/sprintf("%.3d",$1)/eg if $b2 =~ /^(APP)?[.0-9 ]*$/ and length($b2)<16;
         $caseInsensitive and $rtnVal = (lc($a2) cmp lc($b2));
         $rtnVal or $rtnVal = ($a2 cmp $b2);
     }
@@ -1257,7 +1257,7 @@ sub WriteTagNames($$)
                             $prt = "= $$printConv{$key}";
                             if ($$printConv{PrintHex}) {
                                 $index = sprintf('0x%x',$index);
-                            } elsif ($index !~ /^[-+]?\d+$/) {
+                            } elsif ($index !~ /^[+-]?(?=\d|\.\d)\d*(\.\d*)?$/) {
                                 $index = "'" . EscapeHTML($index) . "'";
                             }
                         } else {
