@@ -6,8 +6,9 @@
 # Revisions:    11/25/2003  - P. Harvey Created
 #
 # References:   1) http://park2.wakwak.com/~tsuruzoh/Computer/Digicams/exif-e.html
-#               2) Christian Koller private communication (tests with the 20D)
-#               3) Rainer Honle private communication (tests with the 5D)
+#               2) Christian Koller private communication (20D)
+#               3) Rainer Honle private communication (5D)
+#               4) David Pitcher private communication (1DmkIII firmware upgrade)
 #------------------------------------------------------------------------------
 
 package Image::ExifTool::CanonCustom;
@@ -18,7 +19,7 @@ use Image::ExifTool qw(:DataAccess);
 use Image::ExifTool::Canon;
 use Image::ExifTool::Exif;
 
-$VERSION = '1.19';
+$VERSION = '1.21';
 
 sub ProcessCanonCustom($$$);
 sub ProcessCanonCustom2($$$);
@@ -1201,8 +1202,8 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
     0x0101 => [
         {
             Name => 'ExposureLevelIncrements',
-            Condition => '$$self{Model} =~ /\b40D\b/',
-            Notes => '40D',
+            Condition => '$$self{Model} =~ /\b(40D|450D|XSi|Kiss X2)\b/',
+            Notes => '40D and 450D',
             PrintConv => {
                 0 => '1/3 Stop',
                 1 => '1/2 Stop',
@@ -1399,6 +1400,15 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
                 1 => '1/250 Fixed',
             },
         },
+        {
+            Name => 'FlashSyncSpeedAv',
+            Condition => '$$self{Model} =~ /\b(450D|XSi|Kiss X2)\b/',
+            Notes => '450D',
+            PrintConv => {
+                0 => 'Auto',
+                1 => '1/200 Fixed',
+            },
+        },
         {
             Name => 'FlashSyncSpeedAv',
             Notes => '1D Mark III',
@@ -1548,6 +1558,9 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
             0 => '19 points',
             1 => 'Inner 9 points',
             2 => 'Outer 9 points',
+            3 => '19 Points, Multi-controller selectable', #4
+            4 => 'Inner 9 Points, Multi-controller selectable', #4
+            5 => 'Outer 9 Points, Multi-controller selectable', #4
         },
     },
     0x050a => {
@@ -1598,14 +1611,27 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
         Name => 'SuperimposedDisplay',
         PrintConv => \%onOff,
     },
-    0x0511 => { # new for 40D
-        Name => 'AFDuringLiveView',
-        PrintConv => \%disableEnable,
-    },
+    0x0511 => [ # new for 40D
+        {
+            Name => 'AFDuringLiveView',
+            Condition => '$$self{Model} =~ /\b40D\b/',
+            Notes => '40D',
+            PrintConv => \%disableEnable,
+        },
+        {
+            Name => 'AFDuringLiveView',
+            Notes => '450D',
+            PrintConv => {
+                0 => 'Disable',
+                1 => 'Quick mode',
+                2 => 'Live mode',
+            },
+        },
+    ],
     #### 3b) Drive
     0x060f => {
         Name => 'MirrorLockup',
-        Notes => 'value of 2 not used by 40D',
+        Notes => 'value of 2 not used by 40D or 450D',
         PrintConv => {
             0 => 'Disable',
             1 => 'Enable',
@@ -1659,6 +1685,8 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
             0 => 'Exposure comp/Aperture',
             1 => 'AF point selection',
             2 => 'ISO speed',
+            3 => 'AF point selection swapped with Exposure comp', #4
+            4 => 'ISO speed swapped with Exposure comp', #4
         },
     },
     0x0704 => [
@@ -1674,6 +1702,18 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
                 4 => 'Image playback',
             },
         },
+        {
+            Name => 'SetButtonWhenShooting',
+            Condition => '$$self{Model} =~ /\b(450D|XSi|Kiss X2)\b/',
+            Notes => '450D',
+            PrintConv => {
+                0 => 'Normal (disabled)',
+                1 => 'Image quality',
+                2 => 'Flash exposure compensation',
+                3 => 'LCD Monitor On/Off',
+                4 => 'Menu display',
+            },
+        },
         {
             Name => 'SetButtonWhenShooting',
             Notes => '1D Mark III',
@@ -2059,7 +2099,8 @@ under the same terms as Perl itself.
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to Christian Koller for his work in decoding the 20D custom
-functions, and Rainer Honle for decoding the 5D custom functions.
+functions, Rainer Honle for decoding the 5D custom functions and David
+Pitcher for adding a few undocumented 1DmkIII settings.
 
 =head1 SEE ALSO
 
