@@ -1,7 +1,7 @@
 #------------------------------------------------------------------------------
 # File:         NikonCapture.pm
 #
-# Description:  Read/Write Nikon Capture information
+# Description:  Read/write Nikon Capture information
 #
 # Revisions:    11/08/2005 - P. Harvey Created
 #
@@ -15,7 +15,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.02';
+$VERSION = '1.03';
 
 # common print conversions
 my %offOn = ( 0 => 'Off', 1 => 'On' );
@@ -248,9 +248,9 @@ my %unsharpColor = (
     FORMAT => 'int32u',
     FIRST_ENTRY => 0,
     GROUPS => { 0 => 'MakerNotes', 2 => 'Image' },
-    0 => 'D-LightingHSShadow',
-    1 => 'D-LightingHSHighlight',
-    2 => 'D-LightingHSColorBoost',
+    0 => 'D-LightingHQShadow',
+    1 => 'D-LightingHQHighlight',
+    2 => 'D-LightingHQColorBoost',
 );
 
 %Image::ExifTool::NikonCapture::ColorBoost = (
@@ -642,7 +642,7 @@ sub ProcessNikonCapture($$$)
 
 =head1 NAME
 
-Image::ExifTool::NikonCapture - Read/Write Nikon Capture information
+Image::ExifTool::NikonCapture - Read/write Nikon Capture information
 
 =head1 SYNOPSIS
 
@@ -655,7 +655,7 @@ the maker notes of NEF images.
 
 =head1 AUTHOR
 
-Copyright 2003-2007, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2008, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
