@@ -3,8 +3,8 @@
 #
 # Description:  Read PDF meta information
 #
-# Revisions:    07/11/05 - P. Harvey Created
-#               07/25/05 - P. Harvey Add support for encrypted documents
+# Revisions:    07/11/2005 - P. Harvey Created
+#               07/25/2005 - P. Harvey Add support for encrypted documents
 #
 # References:   1) http://partners.adobe.com/public/developer/pdf/index_reference.html
 #               2) http://search.cpan.org/dist/Crypt-RC4/
@@ -17,7 +17,7 @@ use vars qw($VERSION $AUTOLOAD);
 use Image::ExifTool qw(:DataAccess :Utils);
 require Exporter;
 
-$VERSION = '1.13';
+$VERSION = '1.16';
 
 sub FetchObject($$$$);
 sub ExtractObject($$;$$);
@@ -259,6 +259,35 @@ sub WarnOnce($$)
     }
 }
 
+#------------------------------------------------------------------------------
+# Convert PDFDocEncoding characters to Unicode
+# Inputs: 0) PDF text string, 1) Unicode pack format (n,N,v or V)
+# Returns: Unicode string
+my %pdf2unicode = (
+    0x18 => 0x02d8,    0x82 => 0x2021,    0x8c => 0x201e,    0x96 => 0x0152,
+    0x19 => 0x02c7,    0x83 => 0x2026,    0x8d => 0x201c,    0x97 => 0x0160,
+    0x1a => 0x02c6,    0x84 => 0x2014,    0x8e => 0x201d,    0x98 => 0x0178,
+    0x1b => 0x02d9,    0x85 => 0x2013,    0x8f => 0x2018,    0x99 => 0x017d,
+    0x1c => 0x02dd,    0x86 => 0x0192,    0x90 => 0x2019,    0x9a => 0x0131,
+    0x1d => 0x02db,    0x87 => 0x2044,    0x91 => 0x201a,    0x9b => 0x0142,
+    0x1e => 0x02da,    0x88 => 0x2039,    0x92 => 0x2122,    0x9c => 0x0153,
+    0x1f => 0x02dc,    0x89 => 0x203a,    0x93 => 0xfb01,    0x9d => 0x0161,
+    0x80 => 0x2022,    0x8a => 0x2212,    0x94 => 0xfb02,    0x9e => 0x017e,
+    0x81 => 0x2020,    0x8b => 0x2030,    0x95 => 0x0141,    0xa0 => 0x20ac,
+);
+sub PDF2Unicode($$)
+{
+    local $_;
+    my ($val, $fmt) = @_;
+    my @pdf = unpack('C*',$val);
+    foreach (@pdf) {
+        next unless $pdf2unicode{$_};
+        $_ = $pdf2unicode{$_};
+    }
+    # repack as a Unicode string
+    return pack("$fmt*", @pdf);
+}
+
 #------------------------------------------------------------------------------
 # Convert from PDF to EXIF-style date/time
 # Inputs: 0) PDF date/time string (D:yyyymmddhhmmss+hh'mm')
@@ -861,7 +890,7 @@ sub RC4Crypt($$)
 # Initialize decryption
 # Inputs: 0) ExifTool object reference, 1) Encrypt dictionary reference,
 #         2) ID from file trailer dictionary
-# Returns: error string or undef on success
+# Returns: error string or undef on success (and generates Encryption tag)
 sub DecryptInit($$$)
 {
     my ($exifTool, $encrypt, $id) = @_;
@@ -1085,12 +1114,16 @@ sub ProcessDict($$$$;$$)
             # convert from UTF-16 (big endian) to UTF-8 or Latin if necessary
             # unless this is binary data (hex-encoded strings would not have been converted)
             if (ref $val) {
+                next if ref $val ne 'ARRAY';
                 my $v;
                 foreach $v (@$val) {
                     $exifTool->FoundTag($tagInfo, $v);
                 }
             } else {
-                if ($val =~ s/^\xfe\xff// and not $$tagInfo{Binary}) {
+                if (not $$tagInfo{Binary} and $val =~ /[\x18-\x1f\x80-\xff]/) {
+                    # text string is already in Unicode if it starts with "\xfe\xff",
+                    # otherwise we must first convert from PDFDocEncoding
+                    $val = PDF2Unicode($val, 'n') unless $val =~ s/^\xfe\xff//;
                     $val = $exifTool->Unicode2Charset($val, 'MM');
                 }
                 if ($$tagInfo{List}) {
@@ -1256,7 +1289,7 @@ sub ReadPDF($$)
                 last if $buff =~ s/^\s*trailer\s+//s;
                 $buff =~ s/\s*(\d+)\s+(\d+)\s+//s or return -4;
                 my ($start, $num) = ($1, $2);
-                $num and $raf->Seek(-length($buff), 1) or return -4;
+                $raf->Seek(-length($buff), 1) or return -4;
                 my $i;
                 for ($i=0; $i<$num; ++$i) {
                     $raf->Read($buff, 20) == 20 or return -6;
@@ -1276,7 +1309,8 @@ sub ReadPDF($$)
                         $xref{"$num $gen R"} = $offset;
                     }
                 }
-                %xref or return -4; # xref table may not be empty
+                # (I have a sample from Adobe which has an empty xref table)
+                # %xref or return -4; # xref table may not be empty
                 $buff = '';
             }
             undef $mainFree;    # only do this for the last xref table
