@@ -3,20 +3,21 @@
 #
 # Description:  Read/write Photoshop IRB meta information
 #
-# Revisions:    02/06/04 - P. Harvey Created
-#               02/25/04 - P. Harvey Added hack for problem with old photoshops
-#               10/04/04 - P. Harvey Added a bunch of tags (ref Image::MetaData::JPEG)
-#                          but left most of them commented out until I have enough
-#                          information to write PrintConv routines for them to
-#                          display something useful
-#               07/08/05 - P. Harvey Added support for reading PSD files
-#               01/07/06 - P. Harvey Added PSD write support
-#               11/04/06 - P. Harvey Added handling of resource name
+# Revisions:    02/06/2004 - P. Harvey Created
+#               02/25/2004 - P. Harvey Added hack for problem with old photoshops
+#               10/04/2004 - P. Harvey Added a bunch of tags (ref Image::MetaData::JPEG)
+#                            but left most of them commented out until I have enough
+#                            information to write PrintConv routines for them to
+#                            display something useful
+#               07/08/2005 - P. Harvey Added support for reading PSD files
+#               01/07/2006 - P. Harvey Added PSD write support
+#               11/04/2006 - P. Harvey Added handling of resource name
 #
 # References:   1) http://www.fine-view.com/jp/lab/doc/ps6ffspecsv2.pdf
 #               2) http://www.ozhiker.com/electronics/pjmt/jpeg_info/irb_jpeg_qual.html
 #               3) Matt Mueller private communication (tests with PS CS2)
 #               4) http://www.fileformat.info/format/psd/egff.htm
+#               5) http://www.telegraphics.com.au/svn/psdparse/trunk/resources.c
 #------------------------------------------------------------------------------
 
 package Image::ExifTool::Photoshop;
@@ -25,7 +26,7 @@ use strict;
 use vars qw($VERSION $AUTOLOAD);
 use Image::ExifTool qw(:DataAccess);
 
-$VERSION = '1.33';
+$VERSION = '1.35';
 
 sub ProcessPhotoshop($$$);
 sub WritePhotoshop($$$);
@@ -106,7 +107,7 @@ my %psdMap = (
     0x0409 => {
         Name => 'PhotoshopBGRThumbnail',
         Notes => 'this is a JPEG image, but in BGR format instead of RGB',
-        ValueConv => 'my $img=substr($val,0x1c);$self->ValidateImage(\$img,$tag)',
+        RawConv => 'my $img=substr($val,0x1c);$self->ValidateImage(\$img,$tag)',
     },
     0x040a => {
         Name => 'CopyrightFlag',
@@ -126,7 +127,7 @@ my %psdMap = (
     },
     0x040c => {
         Name => 'PhotoshopThumbnail',
-        ValueConv => 'my $img=substr($val,0x1c);$self->ValidateImage(\$img,$tag)',
+        RawConv => 'my $img=substr($val,0x1c);$self->ValidateImage(\$img,$tag)',
     },
     0x040d => {
         Name => 'GlobalAngle',
@@ -169,12 +170,25 @@ my %psdMap = (
             WriteProc => \&Image::ExifTool::WriteTIFF,
         },
     },
+    0x0423 => { Unknown => 1, Name => 'ExifInfo2', Binary => 1 }, #5
     0x0424 => {
         Name => 'XMP',
         SubDirectory => {
             TagTable => 'Image::ExifTool::XMP::Main',
         },
     },
+    0x0425 => {
+        Name => 'CaptionDigest', #5
+        Writable => 'string',
+        Protected => 1,
+        PrintConv => 'unpack("H*", $val)',
+        PrintConvInv => 'pack("H*", $val)',
+    },
+    0x0426 => { Unknown => 1, Name => 'PrintScale' }, #5
+    0x0428 => { Unknown => 1, Name => 'PixelAspectRatio' }, #5
+    0x0429 => { Unknown => 1, Name => 'LayerComps' }, #5
+    0x042a => { Unknown => 1, Name => 'AlternateDuotoneColors' }, #5
+    0x042b => { Unknown => 1, Name => 'AlternateSpotColors' }, #5
     # 0x07d0-0x0bb6 Path information
     0x0bb7 => { Unknown => 1, Name => 'ClippingPathName' },
     0x2710 => { Unknown => 1, Name => 'PrintFlagsInfo' },
