@@ -9,6 +9,8 @@
 #               2) http://homepage3.nifty.com/kamisaka/makernote/makernote_sony.htm (2006/08/06)
 #               3) Thomas Bodenmann private communication
 #               4) Philippe Devaux private communication (A700)
+#               5) Marcus Holland-Moritz private communication (A700)
+#               JD) Jens Duttke private communication
 #------------------------------------------------------------------------------
 
 package Image::ExifTool::Sony;
@@ -19,12 +21,12 @@ use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 use Image::ExifTool::Minolta;
 
-$VERSION = '1.14';
+$VERSION = '1.19';
 
 sub ProcessSRF($$$);
 sub ProcessSR2($$$);
 
-my %sonyLensIDs;    # filled in based on Minolta LensID's
+my %sonyLensTypes;  # filled in based on Minolta LensType's
 
 %Image::ExifTool::Sony::Main = (
     WRITE_PROC => \&Image::ExifTool::Exif::WriteExif,
@@ -37,12 +39,44 @@ my %sonyLensIDs;    # filled in based on Minolta LensID's
             TagTable => 'Image::ExifTool::PrintIM::Main',
         },
     },
+    0x0102 => { #5/JD
+        Name => 'Quality',
+        Writable => 'int32u',
+        PrintConv => {
+            0 => 'RAW',
+            1 => 'Super Fine',
+            2 => 'Fine',
+            3 => 'Standard',
+            4 => 'Economy',
+            5 => 'Extra Fine',
+            6 => 'RAW + JPEG',
+            7 => 'Compressed RAW',
+            8 => 'Compressed RAW + JPEG',
+        },
+    },
+    0x0104 => { #5/JD
+        Name => 'FlashExposureComp',
+        Description => 'Flash Exposure Compensation',
+        Writable => 'rational64s',
+    },
+    0x0105 => { #5/JD
+        Name => 'Teleconverter',
+        Writable => 'int32u',
+        PrintHex => 1,
+        PrintConv => {
+            0 => 'None',
+            72 => 'Minolta AF 2x APO (D)',
+            80 => 'Minolta AF 2x APO II',
+            136 => 'Minolta AF 1.4x APO (D)',
+            144 => 'Minolta AF 1.4x APO II',
+        },
+    },
     0x2001 => { #PH (A700)
         Name => 'PreviewImage',
         Writable => 'undef',
         DataTag => 'PreviewImage',
         WriteCheck => 'return $val=~/^(none|.{32}\xff\xd8\xff)/s ? undef : "Not a valid image"',
-        ValueConv => q{
+        RawConv => q{
             return $val if $val =~ /^Binary/;
             $val = substr($val,0x20) if length($val) > 0x20;
             return $self->ValidateImage(\$val,$tag);
@@ -71,16 +105,7 @@ my %sonyLensIDs;    # filled in based on Minolta LensID's
     0xb023 => { #PH (A100)
         Name => 'SceneMode',
         Writable => 'int32u',
-        PrintConv => {
-            0 => 'Manual (P,A,S or M)',
-            1 => 'Portrait',
-            4 => 'Sunset',
-            5 => 'Sports',
-            6 => 'Landscape',
-            8 => 'Macro',
-            16 => 'Auto',
-            17 => 'Night Portrait',
-        },
+        PrintConv => \%Image::ExifTool::Minolta::minoltaSceneMode,
     },
     0xb024 => { #PH (A100)
         Name => 'ZoneMatching',
@@ -97,7 +122,12 @@ my %sonyLensIDs;    # filled in based on Minolta LensID's
         PrintConv => {
             0 => 'Off',
             1 => 'Standard',
-            2 => 'Advanced',
+            2 => 'Advanced Auto',
+            8 => 'Advanced Lv1', #JD
+            9 => 'Advanced Lv2', #JD
+            10 => 'Advanced Lv3', #JD
+            11 => 'Advanced Lv4', #JD
+            12 => 'Advanced Lv5', #JD
         },
     },
     0xb026 => { #PH (A100)
@@ -106,13 +136,21 @@ my %sonyLensIDs;    # filled in based on Minolta LensID's
         PrintConv => { 0 => 'Off', 1 => 'On' },
     },
     0xb027 => { #2
-        Name => 'LensID',
+        Name => 'LensType',
         Writable => 'int32u',
-        PrintConv => \%sonyLensIDs,
+        Notes => q{
+            decimal values differentiate lenses which would otherwise have the same
+            LensType, and are used by the Composite LensID tag when attempting to
+            identify the specific lens model
+        },
+        PrintConv => \%sonyLensTypes,
     },
     0xb028 => { #2
         # (used by the DSLR-A100)
         Name => 'MinoltaMakerNote',
+        # must check for zero since apparently a value of zero indicates the IFD doesn't exist
+        # (dumb Sony -- they shouldn't write this tag if the IFD is missing!)
+        Condition => '$$valPt ne "\0\0\0\0"',
         Flags => 'SubIFD',
         SubDirectory => {
             TagTable => 'Image::ExifTool::Minolta::Main',
@@ -122,17 +160,7 @@ my %sonyLensIDs;    # filled in based on Minolta LensID's
     0xb029 => { #2
         Name => 'ColorMode',
         Writable => 'int32u',
-        PrintConv => {
-            0 => 'Standard',
-            1 => 'Vivid',
-            2 => 'Portrait',
-            3 => 'Landscape',
-            4 => 'Sunset',
-            5 => 'Night Scene',
-            6 => 'B&W',
-            7 => 'Adobe RGB',
-            12 => 'Neutral', #4
-        },
+        PrintConv => \%Image::ExifTool::Minolta::sonyColorMode,
     },
     0xb040 => { #2
         Name => 'Macro',
@@ -261,14 +289,30 @@ my %sonyLensIDs;    # filled in based on Minolta LensID's
     },
 );
 
-# fill in Sony LensID lookup based on Minolta values
+# fill in Sony LensType lookup based on Minolta values
 {
-    %sonyLensIDs = %Image::ExifTool::Minolta::minoltaLensIDs;
+    %sonyLensTypes = %Image::ExifTool::Minolta::minoltaLensTypes;
     my $id;
-    foreach $id (keys %Image::ExifTool::Minolta::minoltaLensIDs) {
+    foreach $id (sort { $a <=> $b } keys %Image::ExifTool::Minolta::minoltaLensTypes) {
         # higher numbered lenses are missing last digit of ID for some Sony models
         next if $id < 10000;
-        $sonyLensIDs{int($id/10)} = $Image::ExifTool::Minolta::minoltaLensIDs{$id};
+        my $sid = int($id/10);
+        my $i;
+        my $lens = $Image::ExifTool::Minolta::minoltaLensTypes{$id};
+        if ($sonyLensTypes{$sid}) {
+            # put lens name with "or" first in list
+            if ($lens =~ / or /) {
+                my $tmp = $sonyLensTypes{$sid};
+                $sonyLensTypes{$sid} = $lens;
+                $lens = $tmp;
+            }
+            for (;;) {
+                $i = ($i || 0) + 1;
+                $sid = int($id/10) . ".$i";
+                last unless $sonyLensTypes{$sid};
+            }
+        }
+        $sonyLensTypes{$sid} = $lens;
     }
 }
 
@@ -375,23 +419,36 @@ sub ProcessSRF($$$)
 sub ProcessSR2($$$)
 {
     my ($exifTool, $dirInfo, $tagTablePtr) = @_;
+    my $raf = $$dirInfo{RAF};
     my $dataPt = $$dirInfo{DataPt};
+    my $dataPos = $$dirInfo{DataPos};
+    my $dataLen = $$dirInfo{DataLen} || length $$dataPt;
+    my $base = $$dirInfo{Base} || 0;
+
+    # make sure we have the first 4 bytes available to test directory type
+    my $buff;
+    if ($dataLen < 4 and $raf) {
+        my $pos = $dataPos + ($$dirInfo{DirStart}||0) + $base;
+        if ($raf->Seek($pos, 0) and $raf->Read($buff, 4) == 4) {
+            $dataPt = \$buff;
+            undef $$dirInfo{DataPt};    # must load data from file
+            $raf->Seek($pos, 0);
+        }
+    }
     # this may either be a normal IFD, or a MRW-file-like data block in newer ARW images
     if ($dataPt and $$dataPt =~ /^\0MR[IM]/) {
         require Image::ExifTool::MinoltaRaw;
         return Image::ExifTool::MinoltaRaw::ProcessMRW($exifTool, $dirInfo);
     }
-    my $dataPos = $$dirInfo{DataPos};
-    my $dataLen = $$dirInfo{DataLen} || length $$dataPt;
     my $dirLen = $$dirInfo{DirLen};
     my $verbose = $exifTool->Options('Verbose');
     my $result = Image::ExifTool::Exif::ProcessExif($exifTool, $dirInfo, $tagTablePtr);
     return $result unless $result;
-    my $offset = $exifTool->{SR2SubIFDOffset};
+    # only take first offset value if more than one!
+    my @offsets = split ' ', $exifTool->{SR2SubIFDOffset};
+    my $offset = shift @offsets;
     my $length = $exifTool->{SR2SubIFDLength};
     my $key = $exifTool->{SR2SubIFDKey};
-    my $raf = $$dirInfo{RAF};
-    my $base = $$dirInfo{Base} || 0;
     if ($offset and $length and defined $key) {
         my $buff;
         # read encrypted SR2SubIFD from file
@@ -413,16 +470,23 @@ sub ProcessSR2($$$)
                 $parms{MaxLen} = 96 unless $verbose > 3;
                 Image::ExifTool::HexDump(\$buff, $length, %parms);
             }
-            my %dirInfo = (
-                Base => $base,
-                DataPt => \$buff,
-                DataLen => length $buff,
-                DirStart => 0,
-                DirName => 'SR2SubIFD',
-                DataPos => $offset,
-            );
-            my $subTable = Image::ExifTool::GetTagTable('Image::ExifTool::Sony::SR2SubIFD');
-            $result = $exifTool->ProcessDirectory(\%dirInfo, $subTable);
+            my $num = '';
+            my $dPos = $offset;
+            for (;;) {
+                my %dirInfo = (
+                    Base => $base,
+                    DataPt => \$buff,
+                    DataLen => length $buff,
+                    DirStart => $offset - $dPos,
+                    DirName => "SR2SubIFD$num",
+                    DataPos => $dPos,
+                );
+                my $subTable = Image::ExifTool::GetTagTable('Image::ExifTool::Sony::SR2SubIFD');
+                $result = $exifTool->ProcessDirectory(\%dirInfo, $subTable);
+                last unless @offsets;
+                $offset = shift @offsets;
+                $num = ($num || 1) + 1;
+            }
 
         } else {
             $exifTool->Warn('Error reading SR2 data');
@@ -476,7 +540,7 @@ under the same terms as Perl itself.
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks to Thomas Bodenmann for providing information about the LensID's
+Thanks to Thomas Bodenmann for providing information about the LensType's
 and Philippe Devaux for decoding a ColorMode value.
 
 =head1 SEE ALSO
